use pkg_config::Config;
use std::env;
use std::path::Path;

fn bindgen_headers(path: &str) {
    let arch = env::var("CARGO_CFG_TARGET_ARCH");
    let mut bindgen = bindgen::Builder::default()
        .header(path)
        .derive_eq(true)
        .layout_tests(false);
    if let Ok("wasm32") = arch.as_ref().map(String::as_str) {
        bindgen = bindgen.clang_arg("-fvisibility=default");
    }
    let bindings = bindgen.generate().expect("bindgen");
    let out_dir = env::var_os("OUT_DIR").expect("OUT_DIR");
    let out_path = Path::new(&out_dir);
    bindings
        .write_to_file(out_path.join("bindings.rs"))
        .expect("Couldn't write bindings!");
}

pub fn main() {
    let lib = Config::new().atleast_version("6.8.0").probe("oniguruma").unwrap();
    for path in &lib.include_paths {
        let header = path.join("oniguruma.h");
        if header.exists() {
            bindgen_headers(&header.display().to_string());
            return;
        }

        panic!(
            "Unable to find oniguruma.h in include paths from pkg-config: {:?}",
            lib.include_paths
        );
    }
}
